@@ -5,6 +5,10 @@ import json
 from io import BytesIO
 from gzip import GzipFile
 from botocore.exceptions import ClientError
+from pandas.api.types import is_string_dtype
+from pandas.api.types import is_object_dtype
+from pandas.api.types import is_float_dtype
+from pandas.api.types import is_integer_dtype
 
 def load_s3_file(s3_res, s3_bucket_name, s3_key):
 
@@ -158,10 +162,14 @@ def upload_data_to_s3(s3_res, s3_bucket_name, s3_key, data, gzip_it, output_form
 			# Else: Store everything as string and fill in empty strings for null-values
 			if 'dt' in kwargs:
 				for key, value in kwargs['dt'].items():
-					if key in columns:
+					if key in df_columns:
 						try:
 							if value == 'datetime':
 								df[key] = pd.to_datetime(df[key])
+							elif value == 'int64':
+								df[key] = df[key].fillna(0).astype(value)
+							elif value == 'float64':
+								df[key] = df[key].fillna(0.0).astype(value)
 							elif value == 'leave_alone':
 								pass
 							else:
@@ -175,15 +183,26 @@ def upload_data_to_s3(s3_res, s3_bucket_name, s3_key, data, gzip_it, output_form
 			
 			# default rest of data to string
 			for key in df_columns.keys():
-				if df_columns[key] == object:
+				print(key)
+				if is_string_dtype(df[key]):
+					print("string")
+					df[key] = df[key].fillna("").astype(str)
+				elif is_float_dtype(df[key]):
+					print("float")
+					df[key] = df[key].fillna(0).astype(int).astype(str).replace("0", "")
+				elif is_integer_dtype(df[key]):
+					print("integer")
+					df[key] = df[key].fillna(0).astype(str).replace("0", "")
+				elif is_object_dtype(df[key]):
+					print("object")
+					# df[key] = df[key].fillna("").astype(str)
 					try:
 						df[key] = df[key].fillna("").apply(json.dumps)
 					except:
 						df[key] = df[key].fillna("").astype(str)
-				if df_columns[key] == float:
-					df[key] = df[key].fillna(0).astype(int).astype(str).replace("0", "")
-				if df_columns[key] == int:
-					df[key] = df[key].fillna(0).astype(str).replace("0", "")
+				else:
+					print("else")
+					pass
 
 			table = pa.Table.from_pandas(df)
 			
